# jacob-os-version-check 
### Development enviroment setting
``` bash

# install PDM
# git clone ... 
$ source .venv/bin/activate
$ pdm install
# $ vi .... (coding)
# TEST
$ pdm install
$ pdm test
$ pip install . 
$ git add  <file_name>
$ git commit -a
$ git push
$ pdm publish
```

# Usage
```python
$ pip install jacob_os_version_check
$ python
>>> from jacob_os_version_check.hi import hi
>>> hi()
```
